@@ -1,45 +1,53 @@
 """Test cucumber json output."""
+from __future__ import annotations
+
 import json
 import os.path
 import textwrap
+from typing import TYPE_CHECKING, Any
+
+if TYPE_CHECKING:
+    from _pytest.pytester import Pytester, RunResult
 
 
-def runandparse(testdir, *args):
+def runandparse(pytester: Pytester, *args: Any) -> tuple[RunResult, list[dict[str, Any]]]:
     """Run tests in testdir and parse json output."""
-    resultpath = testdir.tmpdir.join("cucumber.json")
-    result = testdir.runpytest('--cucumberjson={0}'.format(resultpath), '-s', *args)
-    jsonobject = json.load(resultpath.open())
+    resultpath = pytester.path.joinpath("cucumber.json")
+    result = pytester.runpytest(f"--cucumberjson={resultpath}", "-s", *args)
+    with resultpath.open() as f:
+        jsonobject = json.load(f)
     return result, jsonobject
 
 
-class equals_any(object):
+class OfType:
+    """Helper object to help compare object type to initialization type"""
 
-    """Helper object comparison to which is always 'equal'."""
-
-    def __init__(self, type=None):
+    def __init__(self, type: type = None) -> None:
         self.type = type
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         return isinstance(other, self.type) if self.type else True
 
-    def __cmp__(self, other):
-        return 0 if (isinstance(other, self.type) if self.type else False) else -1
 
-
-string = type(u'')
-
-
-def test_step_trace(testdir):
+def test_step_trace(pytester):
     """Test step trace."""
-    testdir.makefile(".ini", pytest=textwrap.dedent("""
+    pytester.makefile(
+        ".ini",
+        pytest=textwrap.dedent(
+            """
     [pytest]
     markers =
         scenario-passing-tag
         scenario-failing-tag
         scenario-outline-passing-tag
         feature-tag
-    """))
-    testdir.makefile('.feature', test=textwrap.dedent("""
+    """
+        ),
+    )
+    pytester.makefile(
+        ".feature",
+        test=textwrap.dedent(
+            """
     @feature-tag
     Feature: One passing scenario, one failing scenario
 
@@ -54,7 +62,7 @@ def test_step_trace(testdir):
             And a failing step
 
         @scenario-outline-passing-tag
-        Scenario: Passing outline
+        Scenario Outline: Passing outline
             Given type <type> and value <value>
 
             Examples: example1
@@ -62,25 +70,29 @@ def test_step_trace(testdir):
             | str     | hello  |
             | int     | 42     |
             | float   | 1.0    |
-    """))
-    testdir.makepyfile(textwrap.dedent("""
+    """
+        ),
+    )
+    pytester.makepyfile(
+        textwrap.dedent(
+            """
         import pytest
-        from pytest_bdd import given, when, scenario
+        from pytest_bdd import given, when, scenario, parsers
 
         @given('a passing step')
-        def a_passing_step():
+        def _():
             return 'pass'
 
         @given('some other passing step')
-        def some_other_passing_step():
+        def _():
             return 'pass'
 
         @given('a failing step')
-        def a_failing_step():
+        def _():
             raise Exception('Error')
 
-        @given('type <type> and value <value>')
-        def type_type_and_value_value():
+        @given(parsers.parse('type {type} and value {value}'))
+        def _():
             return 'pass'
 
         @scenario('test.feature', 'Passing')
@@ -94,8 +106,12 @@ def test_step_trace(testdir):
         @scenario('test.feature', 'Passing outline')
         def test_passing_outline():
             pass
-    """))
-    result, jsonobject = runandparse(testdir)
+    """
+        )
+    )
+    result, jsonobject = runandparse(pytester)
+    result.assert_outcomes(passed=4, failed=1)
+
     assert result.ret
     expected = [
         {
@@ -111,36 +127,20 @@ def test_step_trace(testdir):
                         {
                             "keyword": "Given",
                             "line": 6,
-                            "match": {
-                                "location": ""
-                            },
+                            "match": {"location": ""},
                             "name": "a passing step",
-                            "result": {
-                                "status": "passed",
-                                "duration": equals_any(int)
-                            }
+                            "result": {"status": "passed", "duration": OfType(int)},
                         },
                         {
                             "keyword": "And",
                             "line": 7,
-                            "match": {
-                                "location": ""
-                            },
+                            "match": {"location": ""},
                             "name": "some other passing step",
-                            "result": {
-                                "status": "passed",
-                                "duration": equals_any(int)
-                            }
-                        }
-
+                            "result": {"status": "passed", "duration": OfType(int)},
+                        },
                     ],
-                    "tags": [
-                        {
-                            'name': 'scenario-passing-tag',
-                            'line': 4,
-                        }
-                    ],
-                    "type": "scenario"
+                    "tags": [{"name": "scenario-passing-tag", "line": 4}],
+                    "type": "scenario",
                 },
                 {
                     "description": "",
@@ -152,170 +152,83 @@ def test_step_trace(testdir):
                         {
                             "keyword": "Given",
                             "line": 11,
-                            "match": {
-                                "location": ""
-                            },
+                            "match": {"location": ""},
                             "name": "a passing step",
-                            "result": {
-                                "status": "passed",
-                                "duration": equals_any(int)
-                            }
+                            "result": {"status": "passed", "duration": OfType(int)},
                         },
                         {
                             "keyword": "And",
                             "line": 12,
-                            "match": {
-                                "location": ""
-                            },
+                            "match": {"location": ""},
                             "name": "a failing step",
-                            "result": {
-                                "error_message": equals_any(string),
-                                "status": "failed",
-                                "duration": equals_any(int)
-                            }
-                        }
+                            "result": {"error_message": OfType(str), "status": "failed", "duration": OfType(int)},
+                        },
                     ],
-                    "tags": [
-                        {
-                            'name': 'scenario-failing-tag',
-                            'line': 9,
-                        }
-                    ],
-                    "type": "scenario"
+                    "tags": [{"name": "scenario-failing-tag", "line": 9}],
+                    "type": "scenario",
                 },
                 {
                     "description": "",
                     "keyword": "Scenario",
-                    "tags": [
-                        {
-                            "line": 14,
-                            "name": "scenario-outline-passing-tag"
-                        }
-                    ],
+                    "tags": [{"line": 14, "name": "scenario-outline-passing-tag"}],
                     "steps": [
                         {
                             "line": 16,
                             "match": {"location": ""},
-                            "result": {
-                                "status": "passed",
-                                "duration": equals_any(int)
-                            },
+                            "result": {"status": "passed", "duration": OfType(int)},
                             "keyword": "Given",
-                            "name": "type <type> and value <value>"
+                            "name": "type str and value hello",
                         }
                     ],
                     "line": 15,
                     "type": "scenario",
                     "id": "test_passing_outline[str-hello]",
-                    "name": "Passing outline"
+                    "name": "Passing outline",
                 },
                 {
                     "description": "",
                     "keyword": "Scenario",
-                    "tags": [
-                        {
-                            "line": 14,
-                            "name": "scenario-outline-passing-tag"
-                        }
-                    ],
+                    "tags": [{"line": 14, "name": "scenario-outline-passing-tag"}],
                     "steps": [
                         {
                             "line": 16,
                             "match": {"location": ""},
-                            "result": {
-                                "status": "passed",
-                                "duration": equals_any(int)
-                            },
+                            "result": {"status": "passed", "duration": OfType(int)},
                             "keyword": "Given",
-                            "name": "type <type> and value <value>"
+                            "name": "type int and value 42",
                         }
                     ],
                     "line": 15,
                     "type": "scenario",
                     "id": "test_passing_outline[int-42]",
-                    "name": "Passing outline"
+                    "name": "Passing outline",
                 },
                 {
                     "description": "",
                     "keyword": "Scenario",
-                    "tags": [
-                        {
-                            "line": 14,
-                            "name": "scenario-outline-passing-tag"
-                        }
-                    ],
+                    "tags": [{"line": 14, "name": "scenario-outline-passing-tag"}],
                     "steps": [
                         {
                             "line": 16,
                             "match": {"location": ""},
-                            "result": {
-                                "status": "passed",
-                                "duration": equals_any(int)
-                            },
+                            "result": {"status": "passed", "duration": OfType(int)},
                             "keyword": "Given",
-                            "name": "type <type> and value <value>"
+                            "name": "type float and value 1.0",
                         }
                     ],
                     "line": 15,
                     "type": "scenario",
                     "id": "test_passing_outline[float-1.0]",
-                    "name": "Passing outline"
-                }
+                    "name": "Passing outline",
+                },
             ],
             "id": os.path.join("test_step_trace0", "test.feature"),
             "keyword": "Feature",
             "line": 2,
             "name": "One passing scenario, one failing scenario",
-            "tags": [
-                {
-                    'name': 'feature-tag',
-                    'line': 1,
-                }
-            ],
-            "uri": os.path.join(testdir.tmpdir.basename, 'test.feature'),
+            "tags": [{"name": "feature-tag", "line": 1}],
+            "uri": os.path.join(pytester.path.name, "test.feature"),
         }
     ]
 
     assert jsonobject == expected
-
-
-def test_step_trace_with_expand_option(testdir):
-    """Test step trace."""
-    testdir.makefile(".ini", pytest=textwrap.dedent("""
-    [pytest]
-    markers =
-        feature-tag
-        scenario-outline-passing-tag
-    """))
-    testdir.makefile('.feature', test=textwrap.dedent("""
-    @feature-tag
-    Feature: One scenario outline, expanded to multiple scenarios
-
-        @scenario-outline-passing-tag
-        Scenario: Passing outline
-            Given type <type> and value <value>
-
-            Examples: example1
-            | type    | value  |
-            | str     | hello  |
-            | int     | 42     |
-            | float   | 1.0    |
-    """))
-    testdir.makepyfile(textwrap.dedent("""
-        import pytest
-        from pytest_bdd import given, scenario
-
-        @given('type <type> and value <value>')
-        def type_type_and_value_value():
-            return 'pass'
-
-        @scenario('test.feature', 'Passing outline')
-        def test_passing_outline():
-            pass
-    """))
-    result, jsonobject = runandparse(testdir, '--cucumber-json-expanded')
-    assert result.ret == 0
-
-    assert jsonobject[0]["elements"][0]["steps"][0]["name"] == "type str and value hello"
-    assert jsonobject[0]["elements"][1]["steps"][0]["name"] == "type int and value 42"
-    assert jsonobject[0]["elements"][2]["steps"][0]["name"] == "type float and value 1.0"
