@@ -3,12 +3,15 @@ import textwrap
 
 import pytest
 
-from pytest_bdd import feature
+from pytest_bdd.parser import get_tags
 
 
-def test_tags_selector(testdir):
+def test_tags_selector(pytester):
     """Test tests selection by tags."""
-    testdir.makefile(".ini", pytest=textwrap.dedent("""
+    pytester.makefile(
+        ".ini",
+        pytest=textwrap.dedent(
+            """
     [pytest]
     markers =
         feature_tag_1
@@ -17,8 +20,12 @@ def test_tags_selector(testdir):
         scenario_tag_02
         scenario_tag_10
         scenario_tag_20
-    """))
-    testdir.makefile('.feature', test="""
+    """
+        ),
+    )
+    pytester.makefile(
+        ".feature",
+        test="""
     @feature_tag_1 @feature_tag_2
     Feature: Tags
 
@@ -30,40 +37,50 @@ def test_tags_selector(testdir):
     Scenario: Tags 2
         Given I have a bar
 
-    """)
-    testdir.makepyfile("""
+    """,
+    )
+    pytester.makepyfile(
+        """
         import pytest
         from pytest_bdd import given, scenarios
 
         @given('I have a bar')
-        def i_have_bar():
+        def _():
             return 'bar'
 
         scenarios('test.feature')
-    """)
-    result = testdir.runpytest('-m', 'scenario_tag_10 and not scenario_tag_01', '-vv')
+    """
+    )
+    result = pytester.runpytest("-m", "scenario_tag_10 and not scenario_tag_01", "-vv")
     outcomes = result.parseoutcomes()
-    assert outcomes['passed'] == 1
-    assert outcomes['deselected'] == 1
+    assert outcomes["passed"] == 1
+    assert outcomes["deselected"] == 1
 
-    result = testdir.runpytest('-m', 'scenario_tag_01 and not scenario_tag_10', '-vv').parseoutcomes()
-    assert result['passed'] == 1
-    assert result['deselected'] == 1
+    result = pytester.runpytest("-m", "scenario_tag_01 and not scenario_tag_10", "-vv").parseoutcomes()
+    assert result["passed"] == 1
+    assert result["deselected"] == 1
 
-    result = testdir.runpytest('-m', 'feature_tag_1', '-vv').parseoutcomes()
-    assert result['passed'] == 2
+    result = pytester.runpytest("-m", "feature_tag_1", "-vv").parseoutcomes()
+    assert result["passed"] == 2
 
-    result = testdir.runpytest('-m', 'feature_tag_10', '-vv').parseoutcomes()
-    assert result['deselected'] == 2
+    result = pytester.runpytest("-m", "feature_tag_10", "-vv").parseoutcomes()
+    assert result["deselected"] == 2
 
 
-def test_tags_after_background_issue_160(testdir):
+def test_tags_after_background_issue_160(pytester):
     """Make sure using a tag after background works."""
-    testdir.makefile(".ini", pytest=textwrap.dedent("""
+    pytester.makefile(
+        ".ini",
+        pytest=textwrap.dedent(
+            """
     [pytest]
     markers = tag
-    """))
-    testdir.makefile('.feature', test="""
+    """
+        ),
+    )
+    pytester.makefile(
+        ".feature",
+        test="""
     Feature: Tags after background
 
         Background:
@@ -75,28 +92,32 @@ def test_tags_after_background_issue_160(testdir):
 
         Scenario: Tags 2
             Given I have a baz
-    """)
-    testdir.makepyfile("""
+    """,
+    )
+    pytester.makepyfile(
+        """
         import pytest
         from pytest_bdd import given, scenarios
 
         @given('I have a bar')
-        def i_have_bar():
+        def _():
             return 'bar'
 
         @given('I have a baz')
-        def i_have_baz():
+        def _():
             return 'baz'
 
         scenarios('test.feature')
-    """)
-    result = testdir.runpytest('-m', 'tag', '-vv').parseoutcomes()
-    assert result['passed'] == 1
-    assert result['deselected'] == 1
+    """
+    )
+    result = pytester.runpytest("-m", "tag", "-vv").parseoutcomes()
+    assert result["passed"] == 1
+    assert result["deselected"] == 1
 
 
-def test_apply_tag_hook(testdir):
-    testdir.makeconftest("""
+def test_apply_tag_hook(pytester):
+    pytester.makeconftest(
+        """
         import pytest
 
         @pytest.hookimpl(tryfirst=True)
@@ -108,8 +129,11 @@ def test_apply_tag_hook(testdir):
             else:
                 # Fall back to pytest-bdd's default behavior
                 return None
-    """)
-    testdir.makefile('.feature', test="""
+    """
+    )
+    pytester.makefile(
+        ".feature",
+        test="""
     Feature: Customizing tag handling
 
         @todo
@@ -119,60 +143,73 @@ def test_apply_tag_hook(testdir):
         @xfail
         Scenario: Tags 2
             Given I have a bar
-    """)
-    testdir.makepyfile("""
+    """,
+    )
+    pytester.makepyfile(
+        """
         from pytest_bdd import given, scenarios
 
         @given('I have a bar')
-        def i_have_bar():
+        def _():
             return 'bar'
 
         scenarios('test.feature')
-    """)
-    result = testdir.runpytest('-rsx')
+    """
+    )
+    result = pytester.runpytest("-rsx")
     result.stdout.fnmatch_lines(["SKIP*: Not implemented yet"])
     result.stdout.fnmatch_lines(["*= 1 skipped, 1 xpassed * =*"])
 
 
-def test_tag_with_spaces(testdir):
-    testdir.makefile(".ini", pytest=textwrap.dedent("""
+def test_tag_with_spaces(pytester):
+    pytester.makefile(
+        ".ini",
+        pytest=textwrap.dedent(
+            """
     [pytest]
     markers =
         test with spaces
-    """))
-    testdir.makeconftest("""
+    """
+        ),
+    )
+    pytester.makeconftest(
+        """
         import pytest
 
         @pytest.hookimpl(tryfirst=True)
         def pytest_bdd_apply_tag(tag, function):
             assert tag == 'test with spaces'
-    """)
-    testdir.makefile('.feature', test="""
+    """
+    )
+    pytester.makefile(
+        ".feature",
+        test="""
     Feature: Tag with spaces
 
         @test with spaces
         Scenario: Tags
             Given I have a bar
-    """)
-    testdir.makepyfile("""
+    """,
+    )
+    pytester.makepyfile(
+        """
         from pytest_bdd import given, scenarios
 
         @given('I have a bar')
-        def i_have_bar():
+        def _():
             return 'bar'
 
         scenarios('test.feature')
-    """)
-    result = testdir.runpytest_subprocess()
-    result.stdout.fnmatch_lines(
-        [
-            "*= 1 passed * =*",
-        ],
+    """
     )
+    result = pytester.runpytest_subprocess()
+    result.stdout.fnmatch_lines(["*= 1 passed * =*"])
 
 
-def test_at_in_scenario(testdir):
-    testdir.makefile('.feature', test="""
+def test_at_in_scenario(pytester):
+    pytester.makefile(
+        ".feature",
+        test="""
     Feature: At sign in a scenario
 
         Scenario: Tags
@@ -180,36 +217,39 @@ def test_at_in_scenario(testdir):
 
         Scenario: Second
             Given I have a baz
-    """)
-    testdir.makepyfile("""
+    """,
+    )
+    pytester.makepyfile(
+        """
         from pytest_bdd import given, scenarios
 
         @given('I have a foo@bar')
-        def i_have_at():
+        def _():
             return 'foo@bar'
 
         @given('I have a baz')
-        def i_have_baz():
+        def _():
             return 'baz'
 
         scenarios('test.feature')
-    """)
-    result = testdir.runpytest_subprocess('--strict')
-    result.stdout.fnmatch_lines(
-        [
-            "*= 2 passed * =*",
-        ],
+    """
     )
+    strict_option = "--strict-markers"
+    result = pytester.runpytest_subprocess(strict_option)
+    result.stdout.fnmatch_lines(["*= 2 passed * =*"])
 
 
-@pytest.mark.parametrize('line, expected', [
-    ('@foo @bar', {'foo', 'bar'}),
-    ('@with spaces @bar', {'with spaces', 'bar'}),
-    ('@double @double', {'double'}),
-    ('    @indented', {'indented'}),
-    (None, set()),
-    ('foobar', set()),
-    ('', set()),
-])
+@pytest.mark.parametrize(
+    "line, expected",
+    [
+        ("@foo @bar", {"foo", "bar"}),
+        ("@with spaces @bar", {"with spaces", "bar"}),
+        ("@double @double", {"double"}),
+        ("    @indented", {"indented"}),
+        (None, set()),
+        ("foobar", set()),
+        ("", set()),
+    ],
+)
 def test_get_tags(line, expected):
-    assert feature.get_tags(line) == expected
+    assert get_tags(line) == expected
